@@ -48,7 +48,7 @@ impl FastRoundResultAccountData {
         Ok(())
     }
 
-    pub fn deserialize(buf: &mut &[u8]) -> Result<Self, std::io::Error> {
+    pub fn deserialize(buf: &[u8]) -> Result<Self, std::io::Error> {
         if buf.len() == 0 || buf[0] != SwitchboardAccountType::TYPE_AGGREGATOR_RESULT_PARSE_OPTIMIZED as u8 {
             return Err(std::io::Error::new(std::io::ErrorKind::InvalidInput, "Invalid buffer account type"));
         }
@@ -64,9 +64,7 @@ impl FastRoundResultAccountData {
 }
 
 pub fn fast_parse_switchboard_result(bytes: &[u8]) -> FastRoundResultAccountData {
-    let mut res = FastRoundResultAccountData {..Default::default()};
-    let buf = res.as_bytes_mut();
-    buf.copy_from_slice(&bytes[1..buf.len()+1]);
+    let res = FastRoundResultAccountData::deserialize(bytes).unwrap();
     return res;
 }
 
